Class: IGMarkets::ClientSentiment
- Defined in:
- lib/ig_markets/client_sentiment.rb
Overview
Contains details on client sentiment for a single market. Returned by DealingPlatform::ClientSentimentMethods#[] and #related_sentiments.
Instance Attribute Summary
Attributes inherited from Model
Instance Method Summary collapse
-
#long_position_percentage ⇒ Float
The long_position_percentage attribute.
-
#market_id ⇒ Object
The market_id attribute.
-
#related_sentiments ⇒ Array<ClientSentiment>
Returns client sentiments for markets that are related to this one.
-
#short_position_percentage ⇒ Float
The short_position_percentage attribute.
Methods inherited from Model
#==, allowed_values, attribute, defined_attribute_names, from, #initialize, #inspect
Constructor Details
This class inherits a constructor from IGMarkets::Model
Instance Method Details
#long_position_percentage ⇒ Float
The long_position_percentage attribute.
5 |
# File 'lib/ig_markets/client_sentiment.rb', line 5 attribute :long_position_percentage, Float |
#market_id ⇒ Object
The market_id attribute.
6 |
# File 'lib/ig_markets/client_sentiment.rb', line 6 attribute :market_id |
#related_sentiments ⇒ Array<ClientSentiment>
Returns client sentiments for markets that are related to this one.
12 13 14 |
# File 'lib/ig_markets/client_sentiment.rb', line 12 def @dealing_platform.gather "clientsentiment/related/#{market_id}", :client_sentiments, ClientSentiment end |
#short_position_percentage ⇒ Float
The short_position_percentage attribute.
7 |
# File 'lib/ig_markets/client_sentiment.rb', line 7 attribute :short_position_percentage, Float |